@@ -8,11 +8,21 @@
 #include <obs-module.h>
 #include <obs-frontend-api.h>
 
-#include "headers/advanced-scene-switcher.hpp"
-#include "headers/status-control.hpp"
-#include "headers/curl-helper.hpp"
-#include "headers/utility.hpp"
-#include "headers/version.h"
+#include "advanced-scene-switcher.hpp"
+#include "status-control.hpp"
+#include "curl-helper.hpp"
+#include "utility.hpp"
+#include "version.h"
+
+const char *obs_module_text(const char *text)
+{
+	return switcher->translate(text);
+}
+
+obs_module_t *obs_current_module()
+{
+	return switcher->modulePtr;
+}
 
 SwitcherData *switcher = nullptr;
 SwitcherData *GetSwitcher()
@@ -66,9 +76,6 @@ void AdvSceneSwitcher::loadUI()
 		(void)DisplayMessage(msg);
 	}
 
-#if __APPLE__
-	setMinimumHeight(700);
-#endif
 	setupGeneralTab();
 	setupTitleTab();
 	setupExecutableTab();
@@ -220,6 +227,8 @@ void SwitcherData::Thread()
 			}
 		}
 
+		ClearWebsocketMessages();
+
 		// After this point we will call frontend functions like
 		// obs_frontend_set_current_scene() and
 		// obs_frontend_set_current_transition()
@@ -478,14 +487,6 @@ bool SwitcherData::anySceneTransitionStarted()
  ******************************************************************************/
 extern "C" void FreeSceneSwitcher()
 {
-	if (loaded_curl_lib) {
-		if (switcher->curl && f_curl_cleanup) {
-			f_curl_cleanup(switcher->curl);
-		}
-		delete loaded_curl_lib;
-		loaded_curl_lib = nullptr;
-	}
-
 	PlatformCleanup();
 
 	delete switcher;
@@ -628,7 +629,7 @@ static void OBSEvent(enum obs_frontend_event event, void *switcher)
 	case OBS_FRONTEND_EVENT_STREAMING_STOPPED:
 		resetLiveTime();
 		break;
-#ifdef REPLAYBUFFER_SUPPORTED
+#if LIBOBS_API_VER >= MAKE_SEMANTIC_VERSION(26, 0, 0)
 	case OBS_FRONTEND_EVENT_REPLAY_BUFFER_SAVED:
 		setReplayBufferSaved();
 		break;
@@ -675,16 +676,14 @@ void LoadPlugins()
 	}
 }
 
-extern "C" void InitSceneSwitcher()
+extern "C" void InitSceneSwitcher(obs_module_t *m, translateFunc t)
 {
 	blog(LOG_INFO, "version: %s", g_GIT_TAG);
 	blog(LOG_INFO, "version: %s", g_GIT_SHA1);
 
 	switcher = new SwitcherData;
-
-	if (loadCurl() && f_curl_init) {
-		switcher->curl = f_curl_init();
-	}
+	switcher->modulePtr = m;
+	switcher->translate = t;
 
 	PlatformInit();
 	LoadPlugins();
