@@ -1,16 +1,11 @@
-#include "headers/advanced-scene-switcher.hpp"
-#include "headers/status-control.hpp"
-#include "headers/utility.hpp"
-#include "headers/version.h"
+#include "advanced-scene-switcher.hpp"
+#include "status-control.hpp"
+#include "utility.hpp"
+#include "version.h"
 
 #include <QFileDialog>
 #include <QStandardPaths>
 
-void AdvSceneSwitcher::on_close_clicked()
-{
-	close();
-}
-
 void AdvSceneSwitcher::reject()
 {
 	close();
@@ -152,7 +147,10 @@ void AdvSceneSwitcher::closeEvent(QCloseEvent *)
 	}
 	switcher->windowPos = this->pos();
 	switcher->windowSize = this->size();
-
+	switcher->macroActionConditionSplitterPosition =
+		ui->macroActionConditionSplitter->sizes();
+	switcher->macroListMacroEditSplitterPosition =
+		ui->macroListMacroEditSplitter->sizes();
 	obs_frontend_save();
 }
 
@@ -195,6 +193,9 @@ void AdvSceneSwitcher::on_uiHintsDisable_stateChanged(int state)
 bool isLegacyTab(const QString &name)
 {
 	return name == obs_module_text(
+			       "AdvSceneSwitcher.sceneGroupTab.title") ||
+	       name == obs_module_text("AdvSceneSwitcher.networkTab.title") ||
+	       name == obs_module_text(
 			       "AdvSceneSwitcher.transitionTab.title") ||
 	       name == obs_module_text(
 			       "AdvSceneSwitcher.windowTitleTab.title") ||
@@ -222,13 +223,13 @@ void AdvSceneSwitcher::on_hideLegacyTabs_stateChanged(int state)
 
 	for (int idx = 0; idx < ui->tabWidget->count(); idx++) {
 		if (isLegacyTab(ui->tabWidget->tabText(idx))) {
-#if defined(_WIN32) || defined(__APPLE__)
-			ui->tabWidget->setTabVisible(idx, !state);
-#else
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 			// TODO: Switch to setTabVisible() once QT 5.15 is more wide spread
 			ui->tabWidget->setTabEnabled(idx, !state);
 			ui->tabWidget->setStyleSheet(
 				"QTabBar::tab::disabled {width: 0; height: 0; margin: 0; padding: 0; border: none;} ");
+#else
+			ui->tabWidget->setTabVisible(idx, !state);
 #endif
 		}
 	}
@@ -501,8 +502,12 @@ void SwitcherData::loadSettings(obs_data_t *obj)
 		return;
 	}
 
+	// Needs to be loaded before any entries which might rely on scene group
+	// selections to be available.
 	loadSceneGroups(obj);
+	loadVariables(obj);
 	loadMacros(obj);
+	loadConnections(obj);
 	loadWindowTitleSwitches(obj);
 	loadScreenRegionSwitches(obj);
 	loadPauseSwitches(obj);
@@ -520,6 +525,7 @@ void SwitcherData::loadSettings(obs_data_t *obj)
 	loadSceneTriggers(obj);
 	loadGeneralSettings(obj);
 	loadHotkeys(obj);
+	loadUISettings(obj);
 
 	// Reset on startup and scene collection change
 	switcher->lastOpenedTab = -1;
@@ -531,11 +537,10 @@ void SwitcherData::saveSettings(obs_data_t *obj)
 		return;
 	}
 
-	// Needs to be loaded before any entries which might rely on scene group
-	// selections to be available.
 	saveSceneGroups(obj);
-
 	saveMacros(obj);
+	saveConnections(obj);
+	saveVariables(obj);
 	saveWindowTitleSwitches(obj);
 	saveScreenRegionSwitches(obj);
 	savePauseSwitches(obj);
@@ -553,6 +558,7 @@ void SwitcherData::saveSettings(obs_data_t *obj)
 	saveSceneTriggers(obj);
 	saveGeneralSettings(obj);
 	saveHotkeys(obj);
+	saveUISettings(obj);
 	saveVersion(obj, g_GIT_SHA1);
 }
 
@@ -593,31 +599,6 @@ void SwitcherData::saveGeneralSettings(obs_data_t *obj)
 	obs_data_set_int(obj, "priority10", functionNamesByPriority[10]);
 
 	obs_data_set_int(obj, "threadPriority", threadPriority);
-
-	obs_data_set_int(obj, "generalTabPos", tabOrder[0]);
-	obs_data_set_int(obj, "macroTabPos", tabOrder[1]);
-	obs_data_set_int(obj, "transitionTabPos", tabOrder[2]);
-	obs_data_set_int(obj, "pauseTabPos", tabOrder[3]);
-	obs_data_set_int(obj, "titleTabPos", tabOrder[4]);
-	obs_data_set_int(obj, "exeTabPos", tabOrder[5]);
-	obs_data_set_int(obj, "regionTabPos", tabOrder[6]);
-	obs_data_set_int(obj, "mediaTabPos", tabOrder[7]);
-	obs_data_set_int(obj, "fileTabPos", tabOrder[8]);
-	obs_data_set_int(obj, "randomTabPos", tabOrder[9]);
-	obs_data_set_int(obj, "timeTabPos", tabOrder[10]);
-	obs_data_set_int(obj, "idleTabPos", tabOrder[11]);
-	obs_data_set_int(obj, "sequenceTabPos", tabOrder[12]);
-	obs_data_set_int(obj, "audioTabPos", tabOrder[13]);
-	obs_data_set_int(obj, "videoTabPos", tabOrder[14]);
-	obs_data_set_int(obj, "networkTabPos", tabOrder[15]);
-	obs_data_set_int(obj, "sceneGroupTabPos", tabOrder[16]);
-	obs_data_set_int(obj, "triggerTabPos", tabOrder[17]);
-
-	obs_data_set_bool(obj, "saveWindowGeo", saveWindowGeo);
-	obs_data_set_int(obj, "windowPosX", windowPos.x());
-	obs_data_set_int(obj, "windowPosY", windowPos.y());
-	obs_data_set_int(obj, "windowWidth", windowSize.width());
-	obs_data_set_int(obj, "windowHeight", windowSize.height());
 }
 
 void SwitcherData::loadGeneralSettings(obs_data_t *obj)
@@ -693,7 +674,69 @@ void SwitcherData::loadGeneralSettings(obs_data_t *obj)
 	obs_data_set_default_int(obj, "threadPriority",
 				 QThread::NormalPriority);
 	threadPriority = obs_data_get_int(obj, "threadPriority");
+}
 
+void saveSplitterPos(QList<int> &sizes, obs_data_t *obj, const std::string name)
+{
+	auto array = obs_data_array_create();
+	for (int i = 0; i < sizes.count(); ++i) {
+		obs_data_t *array_obj = obs_data_create();
+		obs_data_set_int(array_obj, "pos", sizes[i]);
+		obs_data_array_push_back(array, array_obj);
+		obs_data_release(array_obj);
+	}
+	obs_data_set_array(obj, name.c_str(), array);
+	obs_data_array_release(array);
+}
+
+void loadSplitterPos(QList<int> &sizes, obs_data_t *obj, const std::string name)
+{
+	sizes.clear();
+	obs_data_array_t *array = obs_data_get_array(obj, name.c_str());
+	size_t count = obs_data_array_count(array);
+	for (size_t i = 0; i < count; i++) {
+		obs_data_t *item = obs_data_array_item(array, i);
+		sizes << obs_data_get_int(item, "pos");
+		obs_data_release(item);
+	}
+	obs_data_array_release(array);
+}
+
+void SwitcherData::saveUISettings(obs_data_t *obj)
+{
+	obs_data_set_int(obj, "generalTabPos", tabOrder[0]);
+	obs_data_set_int(obj, "macroTabPos", tabOrder[1]);
+	obs_data_set_int(obj, "transitionTabPos", tabOrder[2]);
+	obs_data_set_int(obj, "pauseTabPos", tabOrder[3]);
+	obs_data_set_int(obj, "titleTabPos", tabOrder[4]);
+	obs_data_set_int(obj, "exeTabPos", tabOrder[5]);
+	obs_data_set_int(obj, "regionTabPos", tabOrder[6]);
+	obs_data_set_int(obj, "mediaTabPos", tabOrder[7]);
+	obs_data_set_int(obj, "fileTabPos", tabOrder[8]);
+	obs_data_set_int(obj, "randomTabPos", tabOrder[9]);
+	obs_data_set_int(obj, "timeTabPos", tabOrder[10]);
+	obs_data_set_int(obj, "idleTabPos", tabOrder[11]);
+	obs_data_set_int(obj, "sequenceTabPos", tabOrder[12]);
+	obs_data_set_int(obj, "audioTabPos", tabOrder[13]);
+	obs_data_set_int(obj, "videoTabPos", tabOrder[14]);
+	obs_data_set_int(obj, "networkTabPos", tabOrder[15]);
+	obs_data_set_int(obj, "sceneGroupTabPos", tabOrder[16]);
+	obs_data_set_int(obj, "triggerTabPos", tabOrder[17]);
+
+	obs_data_set_bool(obj, "saveWindowGeo", saveWindowGeo);
+	obs_data_set_int(obj, "windowPosX", windowPos.x());
+	obs_data_set_int(obj, "windowPosY", windowPos.y());
+	obs_data_set_int(obj, "windowWidth", windowSize.width());
+	obs_data_set_int(obj, "windowHeight", windowSize.height());
+
+	saveSplitterPos(macroActionConditionSplitterPosition, obj,
+			"macroActionConditionSplitterPosition");
+	saveSplitterPos(macroListMacroEditSplitterPosition, obj,
+			"macroListMacroEditSplitterPosition");
+}
+
+void SwitcherData::loadUISettings(obs_data_t *obj)
+{
 	obs_data_set_default_int(obj, "generalTabPos", 0);
 	obs_data_set_default_int(obj, "macroTabPos", 1);
 	obs_data_set_default_int(obj, "networkTabPos", 13);
@@ -742,6 +785,10 @@ void SwitcherData::loadGeneralSettings(obs_data_t *obj)
 		     (int)obs_data_get_int(obj, "windowPosY")};
 	windowSize = {(int)obs_data_get_int(obj, "windowWidth"),
 		      (int)obs_data_get_int(obj, "windowHeight")};
+	loadSplitterPos(macroActionConditionSplitterPosition, obj,
+			"macroActionConditionSplitterPosition");
+	loadSplitterPos(macroListMacroEditSplitterPosition, obj,
+			"macroListMacroEditSplitterPosition");
 }
 
 bool SwitcherData::tabOrderValid()
